### 功能
编写基金指标计算的函数库，并且进行单元测试

### 用法
在calcx目录下执行：

1. 运行测试集: <br/>
 `sh run_calx_tests.sh` <br/>
 `python calcx/tests/runtests.py`

<span style='color:red;'>
*注意:* <br/>
*calcx的指标函数定义在*`{XMP_CALCX_HOME}/calcx/__init__.py`*中，*
*如果新增函数，需要在该文件中同时新增*
</span>

**TODO list**

1. 增加更多函数
2. 添加版本控制 
